#[repr(C, u8)]pub enum Modifier {
Static(Keyword),
Final(Keyword),
Abstract(Keyword),
Readonly(Keyword),
Public(Keyword),
PublicSet(Keyword),
Protected(Keyword),
ProtectedSet(Keyword),
Private(Keyword),
PrivateSet(Keyword),
}Expand description
Variants
Static(Keyword)
Final(Keyword)
Abstract(Keyword)
Readonly(Keyword)
Public(Keyword)
PublicSet(Keyword)
Protected(Keyword)
ProtectedSet(Keyword)
Private(Keyword)
PrivateSet(Keyword)
Implementations
Sourceimpl Modifier
impl Modifier
pub fn get_keyword(&self) -> &Keyword
Sourcepub fn is_visibility(&self) -> bool
pub fn is_visibility(&self) -> bool
Returns true if the modifier is a visibility modifier.
Sourcepub fn is_read_visibility(&self) -> bool
pub fn is_read_visibility(&self) -> bool
Returns true if the modifier is a read visibility modifier.
Sourcepub fn is_write_visibility(&self) -> bool
pub fn is_write_visibility(&self) -> bool
Returns true if the modifier is a write visibility modifier.
pub fn as_str<'a>(&self, interner: &'a ThreadedInterner) -> &'a str