#[repr(C)]pub struct NestedVariable {
pub dollar: Span,
pub variable: Box<Variable>,
}Expand description
Represents a nested variable.
A nested variable is a variable that is nested inside another variable, commonly known as a variable variable.
Examples
$$foo
$${foo}
$$$fooFields
dollar: Spanvariable: Box<Variable>Trait Implementations
Sourceimpl Clone for NestedVariable
impl Clone for NestedVariable
Sourcefn clone(&self) -> NestedVariable
fn clone(&self) -> NestedVariable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NestedVariable
impl Debug for NestedVariable
Sourceimpl<'de> Deserialize<'de> for NestedVariable
impl<'de> Deserialize<'de> for NestedVariable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl HasSpan for NestedVariable
impl HasSpan for NestedVariable
Sourceimpl Hash for NestedVariable
impl Hash for NestedVariable
Sourceimpl Ord for NestedVariable
impl Ord for NestedVariable
Sourcefn cmp(&self, other: &NestedVariable) -> Ordering
fn cmp(&self, other: &NestedVariable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NestedVariable
impl PartialEq for NestedVariable
Sourceimpl PartialOrd for NestedVariable
impl PartialOrd for NestedVariable
Sourceimpl Serialize for NestedVariable
impl Serialize for NestedVariable
impl Eq for NestedVariable
impl StructuralPartialEq for NestedVariable